////////// LED color CODE clock
////
////       FOR PCB BOARD 
////
////  A0-A3 time set and 20k pullup resistors
////
////   each sw to input...LOW is active
////
////  ONLY FAULT...hour set is 'AM' ONLY 
////
////  clock only counts to 12 so NO AM,PM


#include <SoftPWM.h>
#include <Wire.h> //SCL=A5, SDA=A4

byte min = 0;    //0-9
byte min10 = 0;  //0-5
byte hour = 0;   //0-9
byte hour10 = 0; //0-1

unsigned long oldtime;
byte oldmin;

boolean updateLED = 1;


///PC board change == pick only one ==

///////////  color array
// start at    0     3       6
// time varr  min   min10    hour
// led wire  B R G  B R G   B  R  G
// index #   0 1 2  3 4 5   6  7  8
//byte pins[]={5,4,3, 8,7,6,  12,2,9 };
//digital pins ^ ^ ^ ^ ^ ^  ^ ^ ^ ^
///PC-01 first board ^^^^^^^^^^^^^^^^


///PC-02 second board vvvvvvvvvvvvvvv
  byte pins[]={4,3,2, 7,6,5, 12,9,8 };
//digital pins ^ ^ ^  ^ ^ ^   ^ ^ ^


void setup() {
  SoftPWMBegin();
  Serial.begin(9600);
  Wire.begin();
  pinMode(A0,INPUT_PULLUP); //always 1023
  pinMode(A1,INPUT_PULLUP);
  pinMode(A2,INPUT_PULLUP);
  pinMode(A3,INPUT_PULLUP);
  pinMode(13,INPUT);

  poleRTC(); 
  
///// next test for single pin and color
// SoftPWMSet(7, 0);   //(pin, 0-255)
// delay(60000);         // 0=bright
////////////////////////////////////////
}

void loop() { 

////pole RTC every 10 sec for changes
if (millis()-oldtime>10000) {
  oldtime=millis;
  poleRTC();
}

if (analogRead(A0)<100 || analogRead(A1)<100 ||
    analogRead(A2)<100 || analogRead(A3)<100) 
 {
  delay(20); //sw debounce ... then 2nd test
if (analogRead(A0)<100 || analogRead(A1)<100 ||
    analogRead(A2)<100 || analogRead(A3)<100) 
   {
    readsw();     
   }
 }


if (updateLED==1) { //updates only if changes
  updateLED=0;
  tprint(); //serial po

 if (hour10==1) {     //hour10  0 or 1
  SoftPWMSet(10,200); //r = bro
  SoftPWMSet(11,250); //g = bro
 } else {
  SoftPWMEnd(10); //r = blk
  SoftPWMEnd(11); //g = blk
 }
 
 if (min==0) { blk(0); }
  if (min10==0) { blk(3); }
   if (hour==0 || hour==10) { blk(6); }
    
 if (min==1) { bro(0); }
  if (min10==1) { bro(3); }
   if (hour==1 || hour==11) { bro(6); }
  
 if (min==2) { red(0); }
  if (min10==2) { red(3); }
   if (hour==2 || hour==12) { red(6); }
  
 if (min==3) { org(0); }
  if (min10==3) { org(3); }
   if (hour==3) { org(6); }
  
 if (min==4) { yel(0); }
  if (min10==4) { yel(3); }
   if (hour==4) { yel(6); }
  
 if (min==5) { gre(0); }
  if (min10==5) { gre(3); }
   if (hour==5) { gre(6); }
  
 if (min==6) { blu(0); }
  if (hour==6) { blu(6); }
 
 if (min==7) { vio(0); }
  if (hour==7) { vio(6); }
 
 if (min==8) { gra(0); }
  if (hour==8) { gra(6); }
 
 if (min==9) { whi(0); }
  if (hour==9) { whi(6); }

} //end updateLED
   
}//// end MAIN end  <<<<<<< >>>>>>>>


//###########################################
//////////////  color functions  ///////
////////////////////////////////////////
//// min 0-9       place=0
//// min10 0-5     place=3
//// hour 0-9      place=6
//// hour10 0-1    none (see above)
////////////////////////////////////////

void blk (byte place) {
  SoftPWMEnd(pins[place]);    //b
  SoftPWMEnd(pins[place+1]);  //r
  SoftPWMEnd(pins[place+2]);  //g
}

void bro (byte place) {
  SoftPWMEnd(pins[place]);    //b
  SoftPWMSet(pins[place+1], 200); //r 
  SoftPWMSet(pins[place+2], 250); //g
}

void red (byte place) {
  SoftPWMEnd(pins[place]);
  SoftPWMSet(pins[place+1], 0);
  SoftPWMEnd(pins[place+2]);  
}

void org (byte place) {
  SoftPWMEnd(pins[place]);     //b
  SoftPWMSet(pins[place+1], 0); //r
  SoftPWMSet(pins[place+2], 210);  //g
}

void yel (byte place) {
  SoftPWMEnd(pins[place]);
  SoftPWMSet(pins[place+1], 0);
  SoftPWMSet(pins[place+2], 110);  
}

void gre (byte place) {
  SoftPWMEnd(pins[place]);     //b
  SoftPWMEnd(pins[place+1]);   //r
  SoftPWMSet(pins[place+2], 0); //g
}

void blu (byte place) {
  SoftPWMSet(pins[place], 0);
  SoftPWMEnd(pins[place+1]);
  SoftPWMEnd(pins[place+2]);  
}

void vio (byte place) {
  SoftPWMSet(pins[place], 210);    //b
  SoftPWMSet(pins[place+1], 0); //r
  SoftPWMEnd(pins[place+2]);   //g
}

void gra (byte place) {
  SoftPWMSet(pins[place], 200);
  SoftPWMSet(pins[place+1], 170);
  SoftPWMSet(pins[place+2], 200);  
}

void whi (byte place) {
  SoftPWMSet(pins[place], 50);    //b
  SoftPWMSet(pins[place+1], 0);  //r
  SoftPWMSet(pins[place+2], 0);  //g
}

//##############################################
/////////////// poleRTC  get clock data

void poleRTC(void) {
 Wire.beginTransmission(0x68); 
 Wire.write(0x01);  //point to min register
 Wire.endTransmission();
 Wire.requestFrom(0x68,2); //2 bits (min,hour)
 byte rtcmin=Wire.read();
 byte rtchour=Wire.read();
 Wire.endTransmission();

 min10=(rtcmin >> 4);  //min10 0-5
 min=(rtcmin & 0xF); //min 0-9
 hour10=((rtchour & 0x10)>>4); //hour10 0-1
 hour=(rtchour & 0xF);  //hour 0-9

 if (min != oldmin) {
 oldmin=min;
 updateLED=1;
 }
} //end poleRTC()

//###########################################
//////////////////readsw  set time

void readsw(void) {
if (analogRead(A3)<100) {
  min++;
  if (min>9) { min=0; }
writeRTC();
}

if (analogRead(A2)<100) {
  min10++;
  if (min10>5) { min10=0; }
writeRTC();
}

//////////  hour set is AM only

if (analogRead(A1)<100) {
  hour++;
  if (hour>9) { hour=0; }
writeRTC();  
}

if (analogRead(A0)<100) {
  hour10++;
  if (hour>1) { hour=0; }
writeRTC();  
}

delay(450); //slows sw press
}

//#############################################
////////////////// writeRTC     /////
void writeRTC(void) {
 Wire.beginTransmission(0x68); 
 Wire.write(0x00);  //point to sec register
 Wire.write(0);   //any set reset sec to 00
 Wire.write((min10<<4) + min); //min 
 Wire.write((hour10<<4) + hour + 64); //hour
 Wire.endTransmission();
 poleRTC();
 updateLED=1; 
}

//###########################################
////////////////// times po   //////

void tprint(void) {
  Serial.print(hour10);
  Serial.print(hour);
  Serial.print(" : ");
  Serial.print(min10);
  Serial.println(min);
}


